==> billogram-foundation-4.7.7.tgz: package/modules/components/fileuploader/FileUploader.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';


export default ({
    block,
    displayName,
    Spinner,
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(!isNullOrEmpty(displayName), 'Missing display name');
    invariant(Spinner !== undefined, 'Missing Spinner component.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            onDragEnd: PropTypes.func,
            onDragEnter: PropTypes.func,
            onDragLeave: PropTypes.func,
            onDragOver: PropTypes.func,
            onFileUpload: PropTypes.func,
            uploading: PropTypes.bool,
        },

        getDefaultProps() {
            return {
                children: null,
                disabled: false,
                onDragEnd: () => {},
                onDragEnter: () => {},
                onDragLeave: () => {},
                onDragOver: () => {},
                onFileUpload: () => {},
                uploading: false,
            };
        },

        componentWillMount() {
            this.metadata = {
                isCustomOpen: false,
                overrideDisable: false,
            };
        },

        open(overrideDisable = false) {
            // less than perfect solution, but we cannot pass a custom context to click.
            this.metadata = {
                overrideDisable,
            };

            this.input.click();
        },

        upload(file) {
            this.props.onFileUpload(file);
        },

        onChange(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            this.upload(evt.target.files[0]);
        },

        onClick(evt) {
            if ((this.props.disabled && !this.metadata.overrideDisable)) {
                evt.preventDefault();
            }

            this.metadata = {
                overrideDisable: false,
            };
        },

        onDragEnd(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            const { disabled, onDragEnd } = this.props;
            if (disabled) {
                return;
            }

            onDragEnd();
        },

        onDragEnter(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            const { disabled, onDragEnter } = this.props;
            if (disabled) {
                return;
            }

            onDragEnter();
        },

        onDragLeave(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            const { disabled, onDragLeave } = this.props;
            if (disabled) {
                return;
            }

            onDragLeave();
        },

        onDragOver(evt) {
            // need to suppress or we won't be able to drop image properly (React bug?).
            evt.preventDefault();
            evt.stopPropagation();

            const { disabled, onDragOver } = this.props;
            if (disabled) {
                return;
            }

            onDragOver();
        },

        onDrop(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            if (this.props.disabled) {
                return;
            }

            this.upload(evt.dataTransfer.files[0]);
        },

        renderDropZone() {
            return (
                <label
                    className={ block('drop-zone') }
                    onClick={ this.onClick }
                    onDragEnter={ this.onDragEnter }
                    onDragEnd={ this.onDragEnd }
                    onDragOver={ this.onDragOver }
                    onDragLeave={ this.onDragLeave }
                    onDrop={ this.onDrop }>
                    <input
                        className={ block('drop-zone-input') }
                        onChange={ this.onChange }
                        ref={ (c) => this.input = c }
                        type="file" />
                    { this.props.children }
                </label>
            );
        },

        renderUploading() {
            return (
                <div className={ block('spinner') }>
                    <Spinner />
                </div>
            );
        },

        render() {
            const { disabled, uploading } = this.props;
            return (
                <div
                    className={ block({ disabled }) }>
                    { uploading ? this.renderUploading() : this.renderDropZone() }
                </div>
            );
        },

    });

};

==> billogram-foundation-4.7.11.tgz: package/modules/components/fileuploader/FileUploader.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';


export default ({
    block,
    displayName,
    Spinner,
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(!isNullOrEmpty(displayName), 'Missing display name');
    invariant(Spinner !== undefined, 'Missing Spinner component.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            onDragEnd: PropTypes.func,
            onDragEnter: PropTypes.func,
            onDragLeave: PropTypes.func,
            onDragOver: PropTypes.func,
            onFileUpload: PropTypes.func,
            uploading: PropTypes.bool,
        },

        getDefaultProps() {
            return {
                children: null,
                disabled: false,
                onDragEnd: () => {},
                onDragEnter: () => {},
                onDragLeave: () => {},
                onDragOver: () => {},
                onFileUpload: () => {},
                uploading: false,
            };
        },

        componentWillMount() {
            this.metadata = {
                isCustomOpen: false,
                overrideDisable: false,
            };
        },

        open(overrideDisable = false) {
            // less than perfect solution, but we cannot pass a custom context to click.
            this.metadata = {
                overrideDisable,
            };

            this.input.click();
        },

        upload(file) {
            this.props.onFileUpload(file);
        },

        onChange(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            this.upload(evt.target.files[0]);
        },

        onClick(evt) {
            if ((this.props.disabled && !this.metadata.overrideDisable)) {
                evt.preventDefault();
            }

            this.metadata = {
                overrideDisable: false,
            };
        },

        onDragEnd(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            const { disabled, onDragEnd } = this.props;
            if (disabled) {
                return;
            }

            onDragEnd();
        },

        onDragEnter(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            const { disabled, onDragEnter } = this.props;
            if (disabled) {
                return;
            }

            onDragEnter();
        },

        onDragLeave(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            const { disabled, onDragLeave } = this.props;
            if (disabled) {
                return;
            }

            onDragLeave();
        },

        onDragOver(evt) {
            // need to suppress or we won't be able to drop image properly (React bug?).
            evt.preventDefault();
            evt.stopPropagation();

            const { disabled, onDragOver } = this.props;
            if (disabled) {
                return;
            }

            onDragOver();
        },

        onDrop(evt) {
            evt.preventDefault();
            evt.stopPropagation();

            if (this.props.disabled) {
                return;
            }

            this.upload(evt.dataTransfer.files[0]);
        },

        renderDropZone() {
            return (
                <div
                    className={ block('drop-zone') }
                    onDragEnter={ this.onDragEnter }
                    onDragEnd={ this.onDragEnd }
                    onDragOver={ this.onDragOver }
                    onDragLeave={ this.onDragLeave }
                    onDrop={ this.onDrop }>
                    <label
                        className={ block('drop-zone-label') }
                        onClick={ this.onClick }>
                        <input
                            className={ block('drop-zone-input') }
                            onChange={ this.onChange }
                            ref={ (c) => this.input = c }
                            type="file" />
                        { this.props.children }
                    </label>
                </div>
            );
        },

        renderUploading() {
            return (
                <div className={ block('spinner') }>
                    <Spinner />
                </div>
            );
        },

        render() {
            const { disabled, uploading } = this.props;
            return (
                <div
                    className={ block({ disabled }) }>
                    { uploading ? this.renderUploading() : this.renderDropZone() }
                </div>
            );
        },

    });

};
